
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/ol_openedx_canvas_integration:canvas_integration_package

from setuptools import setup

setup(**{
    'description': 'An Open edX plugin to add canvas integration support',
    'entry_points': {
        'lms.djangoapp': [
            'ol_openedx_canvas_integration = ol_openedx_canvas_integration.app:CanvasIntegrationConfig',
        ],
    },
    'install_requires': (
        'Django>2.0',
        'celery>=4.4.7',
        'edx-django-utils>4.0.0',
    ),
    'license': 'BSD-3-Clause',
    'name': 'ol-openedx-canvas-integration',
    'namespace_packages': (
    ),
    'package_data': {
        'ol_openedx_canvas_integration': (
            'static/js/canvas_integration.js',
            'templates/canvas_integration.html',
        ),
    },
    'packages': (
        '',
        'ol_openedx_canvas_integration',
        'ol_openedx_canvas_integration.settings',
    ),
    'python_requires': '>=3.8',
    'version': '0.3.0',
})
